@@ -22,8 +22,6 @@ SETTING_VARS = (
         "DEFAULT_DAEMON_LOG_FILE"),
     ("CELERYD_DAEMON_LOG_FORMAT", "LOG_FORMAT",
         "DEFAULT_LOG_FMT"),
-    ("CELERY_TASK_META_USE_DB", "TASK_META_USE_DB",
-        "DEFAULT_TASK_META_USE_DB"),
 )
 
 
