@@ -99,7 +99,9 @@ INSTALLED_APPS = (
     'django.contrib.contenttypes',
     'django.contrib.sessions',
     'django.contrib.sites',
-    'celery'
+    'celery',
+    'someapp',
+    'someappwotask',
 )
 
 try:
